Summary: A firewall daemon with D-Bus interface providing a dynamic firewall
Name: firewalld
Version: 1.2.6
Release: 1%{?dist}
License: GPLv2+
URL:     http://www.firewalld.org
Source0: https://github.com/firewalld/firewalld/releases/download/v%{version}/firewalld-%{version}.tar.gz
Patch5000: firewalld-MDNS-default.patch
BuildArch: noarch
BuildRequires: autoconf, make
BuildRequires: gettext, intltool, docbook-style-xsl, libxslt
BuildRequires: glib2, glib2-devel, python3-devel, systemd-units
BuildRequires: iptables, ebtables, ipset
Requires: iptables, ebtables, ipset
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires: firewalld-filesystem = %{version}-%{release}
Requires: python3-firewall  = %{version}-%{release}
Suggests: iptables-nft
Provides: variant_config(Server)

%description
Firewalld provides a dynamically managed firewall with support for
network/firewall zones that define the trust level of network
connections or interfaces. It has support for IPv4, IPv6 firewall
settings, ethernet bridges and IP sets. There is a separation of
runtime and permanent configuration options. It also provides an
interface for services or applications to add firewall rules directly.

%package -n python3-firewall
Summary: Python3 bindings for firewalld
Requires: python3-dbus, python3-gobject-base, python3-nftables

%description -n python3-firewall
Python3 bindings for firewalld.

%package -n firewalld-filesystem
Summary: Firewalld directory layout and rpm macros

%description -n firewalld-filesystem
This package provides directories and rpm macros which
are required by other packages that add firewalld configuration files.

%package -n firewalld-test
Summary: Firewalld testsuite

%description -n firewalld-test
This package provides the firewalld testsuite.

%prep
%autosetup -p1

%build
export PYTHON="%{__python3}"
%configure --enable-sysconfig --enable-rpmmacros
%make_build

%install
%make_install
install -d -m755 %{buildroot}%{_prefix}/lib/firewalld/zones/

# remove unnecessary files
rm -f %{buildroot}%{_bindir}/firewall-applet
rm -f %{buildroot}%{_bindir}/firewall-config
rm -f %{buildroot}%{_sysconfdir}/xdg/autostart/firewall-applet.desktop
rm -rf %{buildroot}%{_sysconfdir}/firewall
rm -f %{buildroot}%{_datadir}/firewalld/firewall-config.glade
rm -f %{buildroot}%{_datadir}/firewalld/gtk3_chooserbutton.py*
rm -f %{buildroot}%{_datadir}/firewalld/gtk3_niceexpander.py*
rm -f %{buildroot}%{_datadir}/applications/firewall-config.desktop
rm -f %{buildroot}%{_datadir}/metainfo/firewall-config.appdata.xml
rm -f %{buildroot}%{_datadir}/icons/hicolor/*/apps/firewall-config*.*
rm -f %{buildroot}%{_datadir}/icons/hicolor/*/apps/firewall-applet*.*
rm -f %{buildroot}%{_datadir}/glib-2.0/schemas/org.fedoraproject.FirewallConfig.gschema.xml
rm -f %{buildroot}%{_mandir}/man1/firewall-config*.1*
rm -f %{buildroot}%{_mandir}/man1/firewall-applet*.1*
rm -f %{buildroot}%{python3_sitelib}/firewall/__pycache__/*.pyc
rm -f %{buildroot}%{python3_sitelib}/firewall/config/__pycache__/*.pyc
rm -f %{buildroot}%{python3_sitelib}/firewall/core/__pycache__/*.pyc
rm -f %{buildroot}%{python3_sitelib}/firewall/core/io/__pycache__/*.pyc
rm -f %{buildroot}%{python3_sitelib}/firewall/server/__pycache__/*.pyc

%find_lang %{name} --all-name

%post
%systemd_post firewalld.service

%preun
%systemd_preun firewalld.service

%postun
%systemd_postun_with_restart firewalld.service

%files -f %{name}.lang
%license COPYING
%doc README.md
%{_sbindir}/firewalld
%{_bindir}/firewall-cmd
%{_bindir}/firewall-offline-cmd
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/firewall-cmd
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_firewalld
%{_prefix}/lib/firewalld/icmptypes/*.xml
%{_prefix}/lib/firewalld/ipsets/README.md
%{_prefix}/lib/firewalld/policies/*.xml
%{_prefix}/lib/firewalld/services/*.xml
%{_prefix}/lib/firewalld/zones/*.xml
%{_prefix}/lib/firewalld/helpers/*.xml
%config(noreplace) %{_sysconfdir}/firewalld/firewalld.conf
%config(noreplace) %{_sysconfdir}/firewalld/lockdown-whitelist.xml
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/helpers
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/icmptypes
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/ipsets
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/policies
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/services
%attr(0750,root,root) %dir %{_sysconfdir}/firewalld/zones
%defattr(0644,root,root)
%config(noreplace) %{_sysconfdir}/sysconfig/firewalld
%config(noreplace) %{_sysconfdir}/logrotate.d/firewalld
%{_sysconfdir}/modprobe.d/firewalld-sysctls.conf
%{_unitdir}/firewalld.service
%config(noreplace) %{_datadir}/dbus-1/system.d/FirewallD.conf
%{_datadir}/polkit-1
%{_mandir}/man1/firewall*cmd*.1*
%{_mandir}/man1/firewalld*.1*
%{_mandir}/man5/firewall*.5*

%files -n python3-firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/config
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/core/io
%attr(0755,root,root) %dir %{python3_sitelib}/firewall/server
%{python3_sitelib}/firewall/*.py*
%{python3_sitelib}/firewall/config/*.py*
%{python3_sitelib}/firewall/core/*.py*
%{python3_sitelib}/firewall/core/io/*.py*
%{python3_sitelib}/firewall/server/*.py*
%exclude %{python3_sitelib}/firewall/__pycache__/*.pyc
%exclude %{python3_sitelib}/firewall/config/__pycache__/*.pyc
%exclude %{python3_sitelib}/firewall/core/__pycache__/*.pyc
%exclude %{python3_sitelib}/firewall/core/io/__pycache__/*.pyc
%exclude %{python3_sitelib}/firewall/server/__pycache__/*.pyc

%files filesystem
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/helpers
%dir %{_prefix}/lib/firewalld/icmptypes
%dir %{_prefix}/lib/firewalld/ipsets
%dir %{_prefix}/lib/firewalld/policies
%dir %{_prefix}/lib/firewalld/services
%dir %{_prefix}/lib/firewalld/zones
%{_rpmconfigdir}/macros.d/macros.firewalld

%files test
%dir %{_datadir}/firewalld/testsuite
%{_datadir}/firewalld/testsuite/README.md
%{_datadir}/firewalld/testsuite/testsuite
%dir %{_datadir}/firewalld/testsuite/integration
%{_datadir}/firewalld/testsuite/integration/testsuite
%dir %{_datadir}/firewalld/testsuite/python
%{_datadir}/firewalld/testsuite/python/firewalld_config.py
%{_datadir}/firewalld/testsuite/python/firewalld_direct.py
%{_datadir}/firewalld/testsuite/python/firewalld_rich.py
%{_datadir}/firewalld/testsuite/python/firewalld_test.py

%changelog
* Fri Jan 19 2024 Xin Cheng <denisecheng@tencent.com> - 1.2.6-1
- Upgrade to 1.2.6
- rename all README with README.md

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Jun 16 2022 cunshunxia <cunshunxia@tencent.com> - 1.1.0-1
- initial build
